@@ -83,12 +83,17 @@ def get_res_path(path):
     #    cand_path = os.path.join(c_path, path)
     #    if os.path.exists(cand_path):
     #        return cand_path
+    if os.path.isabs(path):
+        return path
+
     resolved = loader.resolve(path)
     if resolved is None:
         if os.path.exists(path):
             return path
 
     if resolved is None:
+        if os.path.exists(path):
+            return path
         raise FileNotFoundError(f"Can't find {path} (searched in ({loader.search_paths}))")
     else:
         return resolved
